@@ -1,14 +1,15 @@
 from numpy import newaxis as na
 from py_wake.utils.gradients import erf
-import numpy as np
+from py_wake import np
 from py_wake.deficit_models import DeficitModel
 from py_wake.deficit_models.deficit_model import ConvectionDeficitModel
-from py_wake.ground_models.ground_models import NoGround, Mirror
-from py_wake.rotor_avg_models.rotor_avg_model import RotorCenter
+from py_wake.ground_models.ground_models import Mirror
 from py_wake.superposition_models import SquaredSum
 from py_wake.wind_farm_models.engineering_models import PropagateDownwind
 from py_wake.utils.gradients import cabs
 from py_wake.utils import gradients
+from py_wake.utils.model_utils import DeprecatedModel
+from py_wake.rotor_avg_models.rotor_avg_model import RotorCenter
 
 
 class BastankhahGaussianDeficit(ConvectionDeficitModel):
@@ -17,18 +18,15 @@ class BastankhahGaussianDeficit(ConvectionDeficitModel):
     A new analytical model for wind-turbine wakes.
     J. Renew. Energy. 2014;70:116-23.
     """
-    args4deficit = ['WS_ilk', 'WS_eff_ilk', 'dw_ijlk', 'cw_ijlk', 'D_src_il', 'ct_ilk']
 
-    def __init__(self, k=0.0324555, ceps=.2, use_effective_ws=False, groundModel=NoGround()):
-        DeficitModel.__init__(self, groundModel=groundModel)
+    def __init__(self, k=0.0324555, ceps=.2, use_effective_ws=False, rotorAvgModel=None, groundModel=None):
+        ConvectionDeficitModel.__init__(self, rotorAvgModel=rotorAvgModel, groundModel=groundModel,
+                                        use_effective_ws=use_effective_ws)
         self._k = k
         self._ceps = ceps
-        self.use_effective_ws = use_effective_ws
-        ConvectionDeficitModel.__init__(self)
 
     def k_ilk(self, **kwargs):
-        shape = np.ones_like(kwargs.get('WS_ilk', np.ones((1, 1, 1))).shape)
-        return np.reshape(self._k, shape)
+        return np.array([[[self._k]]])
 
     def epsilon_ilk(self, ct_ilk, **_):
         # not valid for CT >= 1.
@@ -42,19 +40,22 @@ class BastankhahGaussianDeficit(ConvectionDeficitModel):
         return self.k_ilk(**kwargs)[:, na] * dw_ijlk + \
             self.epsilon_ilk(ct_ilk)[:, na] * D_src_il[:, na, :, na]
 
-    def _calc_deficit(self, WS_ilk, WS_eff_ilk, D_src_il, dw_ijlk, ct_ilk, **kwargs):
-        WS_ref_ilk = (WS_ilk, WS_eff_ilk)[self.use_effective_ws]
+    def _calc_deficit(self, D_src_il, dw_ijlk, ct_ilk, **kwargs):
+        if self.WS_key == 'WS_jlk':
+            WS_ref_ijlk = kwargs[self.WS_key][na]
+        else:
+            WS_ref_ijlk = kwargs[self.WS_key][:, na]
+
         # dimensional wake expansion
-        sigma_sqr_ijlk = (self.sigma_ijlk(D_src_il, dw_ijlk, ct_ilk, **kwargs))**2
+        sigma_sqr_ijlk = (self.sigma_ijlk(D_src_il=D_src_il, dw_ijlk=dw_ijlk, ct_ilk=ct_ilk, **kwargs))**2
         # maximum added to avoid sqrt of negative number
         radical_ijlk = np.maximum(0, (1. - ct_ilk[:, na] * D_src_il[:, na, :, na]**2 / (8. * sigma_sqr_ijlk)))
-        deficit_centre_ijlk = WS_ref_ilk[:, na] * (1. - np.sqrt(radical_ijlk)) * (dw_ijlk > 0)
+        deficit_centre_ijlk = WS_ref_ijlk * (1. - np.sqrt(radical_ijlk)) * (dw_ijlk > 0)
 
-        return WS_ref_ilk, sigma_sqr_ijlk, deficit_centre_ijlk, radical_ijlk
+        return WS_ref_ijlk, sigma_sqr_ijlk, deficit_centre_ijlk, radical_ijlk
 
-    def calc_deficit(self, WS_ilk, WS_eff_ilk, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **kwargs):
-        _, sigma_sqr_ijlk, deficit_centre_ijlk, _ = self._calc_deficit(WS_ilk, WS_eff_ilk, D_src_il, dw_ijlk,
-                                                                       ct_ilk, **kwargs)
+    def calc_deficit(self, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **kwargs):
+        _, sigma_sqr_ijlk, deficit_centre_ijlk, _ = self._calc_deficit(D_src_il, dw_ijlk, ct_ilk, **kwargs)
 
         # term inside exp()
         exponent_ijlk = -1 / (2 * sigma_sqr_ijlk) * cw_ijlk**2
@@ -65,16 +66,18 @@ class BastankhahGaussianDeficit(ConvectionDeficitModel):
 
     def wake_radius(self, D_src_il, dw_ijlk, ct_ilk, **kwargs):
         # according to Niayifar, the wake radius is twice sigma
-        sigma_ijlk = self.sigma_ijlk(D_src_il, dw_ijlk, ct_ilk, **kwargs)
+        sigma_ijlk = self.sigma_ijlk(D_src_il=D_src_il, dw_ijlk=dw_ijlk, ct_ilk=ct_ilk, **kwargs)
         return 2. * sigma_ijlk
 
-    def calc_deficit_convection(self, WS_ilk, WS_eff_ilk, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **kwargs):
-
-        WS_ref_ilk, sigma_sqr_ijlk, deficit_centre_ijlk, radical_ijlk = self._calc_deficit(WS_ilk, WS_eff_ilk,
-                                                                                           D_src_il, dw_ijlk, ct_ilk,
-                                                                                           **kwargs)
+    def calc_deficit_convection(self, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **kwargs):
+        if self.groundModel or (self.rotorAvgModel and not isinstance(self.rotorAvgModel, RotorCenter)):
+            raise NotImplementedError(
+                "calc_deficit_convection (WeightedSum) cannot be used in combination with rotorAvgModels and GroundModels")
+        WS_ref_ijlk, sigma_sqr_ijlk, deficit_centre_ijlk, radical_ijlk = self._calc_deficit(
+            D_src_il, dw_ijlk, ct_ilk, **kwargs)
         # Convection velocity
-        uc_ijlk = WS_ref_ilk[:, na] * 0.5 * (1. + np.sqrt(radical_ijlk))
+        uc_ijlk = WS_ref_ijlk * 0.5 * (1. + np.sqrt(radical_ijlk))
+        sigma_sqr_ijlk = np.broadcast_to(sigma_sqr_ijlk, deficit_centre_ijlk.shape)
 
         return deficit_centre_ijlk, uc_ijlk, sigma_sqr_ijlk
 
@@ -82,9 +85,9 @@ class BastankhahGaussianDeficit(ConvectionDeficitModel):
 class BastankhahGaussian(PropagateDownwind):
     """Predefined wind farm model"""
 
-    def __init__(self, site, windTurbines, k=0.0324555, ceps=.2,
-                 rotorAvgModel=RotorCenter(), superpositionModel=SquaredSum(),
-                 deflectionModel=None, turbulenceModel=None, groundModel=NoGround()):
+    def __init__(self, site, windTurbines, k=0.0324555, ceps=.2, use_effective_ws=False,
+                 rotorAvgModel=None, superpositionModel=SquaredSum(),
+                 deflectionModel=None, turbulenceModel=None, groundModel=None):
         """
         Parameters
         ----------
@@ -94,10 +97,10 @@ class BastankhahGaussian(PropagateDownwind):
             WindTurbines object representing the wake generating wind turbines
         k : float
             Wake expansion factor
-        rotorAvgModel : RotorAvgModel
+        rotorAvgModel : RotorAvgModel, optional
             Model defining one or more points at the down stream rotors to
             calculate the rotor average wind speeds from.\n
-            Defaults to RotorCenter that uses the rotor center wind speed (i.e. one point) only
+            if None, default, the wind speed at the rotor center is used
         superpositionModel : SuperpositionModel, default SquaredSum
             Model defining how deficits sum up
         deflectionModel : DeflectionModel, default None
@@ -105,9 +108,13 @@ class BastankhahGaussian(PropagateDownwind):
         turbulenceModel : TurbulenceModel, default None
             Model describing the amount of added turbulence in the wake
         """
-        PropagateDownwind.__init__(self, site, windTurbines, wake_deficitModel=BastankhahGaussianDeficit(k=k, ceps=ceps, groundModel=groundModel),
-                                   rotorAvgModel=rotorAvgModel, superpositionModel=superpositionModel,
-                                   deflectionModel=deflectionModel, turbulenceModel=turbulenceModel)
+        PropagateDownwind.__init__(self, site, windTurbines,
+                                   wake_deficitModel=BastankhahGaussianDeficit(k=k, ceps=ceps,
+                                                                               use_effective_ws=use_effective_ws,
+                                                                               rotorAvgModel=rotorAvgModel,
+                                                                               groundModel=groundModel),
+                                   superpositionModel=superpositionModel, deflectionModel=deflectionModel,
+                                   turbulenceModel=turbulenceModel)
 
 
 class NiayifarGaussianDeficit(BastankhahGaussianDeficit):
@@ -128,26 +135,23 @@ class NiayifarGaussianDeficit(BastankhahGaussianDeficit):
         indicate that a = [0.35, 0.0] is also a valid selection.
 
     """
-    args4deficit = ['WS_ilk', 'WS_eff_ilk', 'D_src_il',
-                    'dw_ijlk', 'cw_ijlk', 'ct_ilk', 'TI_ilk', 'TI_eff_ilk']
 
     def __init__(self, a=[0.38, 4e-3], ceps=.2, use_effective_ws=False, use_effective_ti=True,
-                 groundModel=NoGround()):
-        DeficitModel.__init__(self, groundModel=groundModel)
+                 rotorAvgModel=None, groundModel=None):
+        DeficitModel.__init__(self, rotorAvgModel=rotorAvgModel, groundModel=groundModel,
+                              use_effective_ws=use_effective_ws, use_effective_ti=use_effective_ti)
         self._ceps = ceps
         self.a = a
-        self.use_effective_ws = use_effective_ws
-        self.use_effective_ti = use_effective_ti
 
     def k_ilk(self, **kwargs):
-        TI_ref_ilk = (kwargs['TI_ilk'], kwargs['TI_eff_ilk'])[self.use_effective_ti]
+        TI_ref_ilk = kwargs[self.TI_key]
         k_ilk = self.a[0] * TI_ref_ilk + self.a[1]
         return k_ilk
 
 
 class NiayifarGaussian(PropagateDownwind):
     def __init__(self, site, windTurbines, a=[0.38, 4e-3], ceps=.2, superpositionModel=SquaredSum(),
-                 deflectionModel=None, turbulenceModel=None, groundModel=NoGround()):
+                 deflectionModel=None, turbulenceModel=None, rotorAvgModel=None, groundModel=None):
         """
         Parameters
         ----------
@@ -162,65 +166,75 @@ class NiayifarGaussian(PropagateDownwind):
         turbulenceModel : TurbulenceModel, default None
             Model describing the amount of added turbulence in the wake
         """
-        PropagateDownwind.__init__(self, site, windTurbines, wake_deficitModel=NiayifarGaussianDeficit(a=a, ceps=ceps, groundModel=groundModel),
-                                   superpositionModel=superpositionModel, deflectionModel=deflectionModel, turbulenceModel=turbulenceModel)
-
-
-class IEA37SimpleBastankhahGaussianDeficit(BastankhahGaussianDeficit):
-    """Implemented according to
-    https://github.com/byuflowlab/iea37-wflo-casestudies/blob/master/iea37-wakemodel.pdf
-
-    Equivalent to BastankhahGaussian for beta=1/sqrt(8) ~ ct=0.9637188
-    """
-    args4deficit = ['WS_ilk', 'D_src_il', 'dw_ijlk', 'cw_ijlk', 'ct_ilk', 'WS_eff_ilk']
-    args4update = ['ct_ilk']
-
-    def __init__(self, groundModel=NoGround()):
-        DeficitModel.__init__(self, groundModel=groundModel)
-        BastankhahGaussianDeficit.__init__(self, k=0.0324555)
-
-    def _calc_layout_terms(self, WS_ilk, D_src_il, dw_ijlk, cw_ijlk, **kwargs):
-        eps = 1e-10
-        sigma_ijlk = self.k_ilk(WS_ilk=WS_ilk) * dw_ijlk * (dw_ijlk > eps) + (D_src_il / np.sqrt(8.))[:, na, :, na]
-        self.layout_factor_ijlk = WS_ilk[:, na] * (dw_ijlk > eps) * np.exp(-0.5 * (cw_ijlk / sigma_ijlk)**2)
-        self.denominator_ijlk = 8. * (sigma_ijlk / D_src_il[:, na, :, na])**2
-
-    def calc_deficit(self, WS_ilk, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **_):
-        if not self.deficit_initalized:
-            self._calc_layout_terms(WS_ilk, D_src_il, dw_ijlk, cw_ijlk)
-        ct_factor_ijlk = (1. - ct_ilk[:, na] / self.denominator_ijlk)
-        # deficit_ijlk
-        return self.layout_factor_ijlk * (1 - np.sqrt(ct_factor_ijlk))
-
-
-class IEA37SimpleBastankhahGaussian(PropagateDownwind):
-    """Predefined wind farm model"""
-
-    def __init__(self, site, windTurbines,
-                 rotorAvgModel=RotorCenter(), superpositionModel=SquaredSum(),
-                 deflectionModel=None, turbulenceModel=None, groundModel=NoGround()):
-        """
-        Parameters
-        ----------
-        site : Site
-            Site object
-        windTurbines : WindTurbines
-            WindTurbines object representing the wake generating wind turbines
-        rotorAvgModel : RotorAvgModel
-            Model defining one or more points at the down stream rotors to
-            calculate the rotor average wind speeds from.\n
-            Defaults to RotorCenter that uses the rotor center wind speed (i.e. one point) only
-        superpositionModel : SuperpositionModel, default SquaredSum
-            Model defining how deficits sum up
-        deflectionModel : DeflectionModel, default None
-            Model describing the deflection of the wake due to yaw misalignment, sheared inflow, etc.
-        turbulenceModel : TurbulenceModel, default None
-            Model describing the amount of added turbulence in the wake
-        """
         PropagateDownwind.__init__(self, site, windTurbines,
-                                   wake_deficitModel=IEA37SimpleBastankhahGaussianDeficit(groundModel=groundModel),
+                                   wake_deficitModel=NiayifarGaussianDeficit(a=a, ceps=ceps,
+                                                                             rotorAvgModel=rotorAvgModel,
+                                                                             groundModel=groundModel),
+                                   superpositionModel=superpositionModel, deflectionModel=deflectionModel,
+                                   turbulenceModel=turbulenceModel)
+
+
+class IEA37SimpleBastankhahGaussianDeficit(BastankhahGaussianDeficit):
+    """Implemented according to
+    https://github.com/byuflowlab/iea37-wflo-casestudies/blob/master/iea37-wakemodel.pdf
+
+    Equivalent to BastankhahGaussian for beta=1/sqrt(8) ~ ct=0.9637188
+    """
+
+    def __init__(self, rotorAvgModel=None, groundModel=None):
+        BastankhahGaussianDeficit.__init__(self, k=0.0324555, groundModel=groundModel, rotorAvgModel=rotorAvgModel)
+
+    def sigma_ijlk(self, WS_ilk, dw_ijlk, D_src_il, **_):
+        # dimensional wake expansion
+        eps = 1e-10
+        return self.k_ilk(WS_ilk=WS_ilk) * dw_ijlk * (dw_ijlk > eps) + (D_src_il / np.sqrt(8.))[:, na, :, na]
+
+    def _calc_layout_terms(self, WS_ilk, D_src_il, dw_ijlk, cw_ijlk, **_):
+        eps = 1e-10
+        sigma_ijlk = self.sigma_ijlk(WS_ilk, dw_ijlk, D_src_il)
+        self.layout_factor_ijlk = WS_ilk[:, na] * ((dw_ijlk > eps) * np.exp(-0.5 * (cw_ijlk / sigma_ijlk)**2))
+        self.denominator_ijlk = 8. * (sigma_ijlk / D_src_il[:, na, :, na])**2
+
+    def calc_deficit(self, WS_ilk, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **_):
+        if not self.deficit_initalized:
+            self._calc_layout_terms(WS_ilk, D_src_il, dw_ijlk, cw_ijlk)
+
+        # ct_factor_ijlk = (1. - ct_ilk[:, na] / self.denominator_ijlk)
+        # # deficit_ijlk
+        # return self.layout_factor_ijlk * (1 - np.sqrt(ct_factor_ijlk))
+
+        return self.layout_factor_ijlk * (1 - np.sqrt((1. - ct_ilk[:, na] / self.denominator_ijlk)))
+
+
+class IEA37SimpleBastankhahGaussian(PropagateDownwind, DeprecatedModel):
+    """Predefined wind farm model"""
+
+    def __init__(self, site, windTurbines,
+                 rotorAvgModel=None, superpositionModel=SquaredSum(),
+                 deflectionModel=None, turbulenceModel=None):
+        """
+        Parameters
+        ----------
+        site : Site
+            Site object
+        windTurbines : WindTurbines
+            WindTurbines object representing the wake generating wind turbines
+        rotorAvgModel : RotorAvgModel, optional
+            Model defining one or more points at the down stream rotors to
+            calculate the rotor average wind speeds from.\n
+            if None, default, the wind speed at the rotor center is used
+        superpositionModel : SuperpositionModel, default SquaredSum
+            Model defining how deficits sum up
+        deflectionModel : DeflectionModel, default None
+            Model describing the deflection of the wake due to yaw misalignment, sheared inflow, etc.
+        turbulenceModel : TurbulenceModel, default None
+            Model describing the amount of added turbulence in the wake
+        """
+        PropagateDownwind.__init__(self, site, windTurbines,
+                                   wake_deficitModel=IEA37SimpleBastankhahGaussianDeficit(),
                                    rotorAvgModel=rotorAvgModel, superpositionModel=superpositionModel,
                                    deflectionModel=deflectionModel, turbulenceModel=turbulenceModel)
+        DeprecatedModel.__init__(self, 'py_wake.literature.iea37_case_study1.IEA37CaseStudy1')
 
 
 class ZongGaussianDeficit(NiayifarGaussianDeficit):
@@ -252,11 +266,11 @@ class ZongGaussianDeficit(NiayifarGaussianDeficit):
         dictates the origin of the far-wake.
 
     """
-    args4deficit = ['WS_ilk', 'WS_eff_ilk', 'D_src_il', 'dw_ijlk', 'cw_ijlk', 'ct_ilk', 'TI_ilk', 'TI_eff_ilk']
 
     def __init__(self, a=[0.38, 4e-3], deltawD=1. / np.sqrt(2), eps_coeff=1. / np.sqrt(8.), lam=7.5, B=3,
-                 use_effective_ws=False, use_effective_ti=True, groundModel=NoGround()):
-        DeficitModel.__init__(self, groundModel=groundModel)
+                 use_effective_ws=False, use_effective_ti=True, rotorAvgModel=None, groundModel=None):
+        DeficitModel.__init__(self, rotorAvgModel=rotorAvgModel, groundModel=groundModel,
+                              use_effective_ws=use_effective_ws, use_effective_ti=use_effective_ti)
         self.a = a
         self.deltawD = deltawD
         # different from Zong, as he effectively took it from Bastankhah 2016, so here
@@ -264,8 +278,6 @@ class ZongGaussianDeficit(NiayifarGaussianDeficit):
         self.eps_coeff = eps_coeff
         self.lam = lam
         self.B = B
-        self.use_effective_ws = use_effective_ws
-        self.use_effective_ti = use_effective_ti
 
     def nw_length(self, ct_ilk, D_src_il, TI_eff_ilk, **_):
         """
@@ -306,7 +318,7 @@ class ZongGaussianDeficit(NiayifarGaussianDeficit):
         return self.eps_coeff * np.ones_like(ct_ilk)
 
     def sigma_ijlk(self, D_src_il, dw_ijlk, ct_ilk, **kwargs):
-        TI_ref_ilk = (kwargs['TI_ilk'], kwargs['TI_eff_ilk'])[self.use_effective_ti]
+        TI_ref_ilk = kwargs[self.TI_key]
         # near-wake length
         xnw_ilk = self.nw_length(ct_ilk, D_src_il, TI_ref_ilk)
         # wake growth rate
@@ -321,8 +333,8 @@ class ZongGaussianDeficit(NiayifarGaussianDeficit):
 
         return sigmaD_ijlk * D_src_il[:, na, :, na]
 
-    def _calc_deficit(self, WS_ilk, WS_eff_ilk, D_src_il, dw_ijlk, ct_ilk, **kwargs):
-        WS_ref_ilk = (WS_ilk, WS_eff_ilk)[self.use_effective_ws]
+    def _calc_deficit(self, D_src_il, dw_ijlk, ct_ilk, **kwargs):
+        WS_ref_ilk = kwargs[self.WS_key]
 
         # dimensional wake expansion rate
         sigma_sqr_ijlk = (self.sigma_ijlk(D_src_il, dw_ijlk, ct_ilk, **kwargs))**2
@@ -338,7 +350,8 @@ class ZongGaussianDeficit(NiayifarGaussianDeficit):
 
 class ZongGaussian(PropagateDownwind):
     def __init__(self, site, windTurbines, a=[0.38, 4e-3], deltawD=1. / np.sqrt(2), lam=7.5, B=3,
-                 superpositionModel=SquaredSum(), deflectionModel=None, turbulenceModel=None, groundModel=NoGround()):
+                 rotorAvgModel=None,
+                 superpositionModel=SquaredSum(), deflectionModel=None, turbulenceModel=None, groundModel=None):
         """
         Parameters
         ----------
@@ -353,8 +366,12 @@ class ZongGaussian(PropagateDownwind):
         turbulenceModel : TurbulenceModel, default None
             Model describing the amount of added turbulence in the wake
         """
-        PropagateDownwind.__init__(self, site, windTurbines, wake_deficitModel=ZongGaussianDeficit(a=a, deltawD=deltawD, lam=lam, B=B, groundModel=groundModel),
-                                   superpositionModel=superpositionModel, deflectionModel=deflectionModel, turbulenceModel=turbulenceModel)
+        PropagateDownwind.__init__(self, site, windTurbines,
+                                   wake_deficitModel=ZongGaussianDeficit(a=a, deltawD=deltawD, lam=lam, B=B,
+                                                                         rotorAvgModel=rotorAvgModel,
+                                                                         groundModel=groundModel),
+                                   superpositionModel=superpositionModel, deflectionModel=deflectionModel,
+                                   turbulenceModel=turbulenceModel)
 
 
 class CarbajofuertesGaussianDeficit(ZongGaussianDeficit):
@@ -378,15 +395,13 @@ class CarbajofuertesGaussianDeficit(ZongGaussianDeficit):
         found by them and incorporated them into the Zong formulation.
 
     """
-    args4deficit = ['WS_ilk', 'WS_eff_ilk', 'D_src_il', 'dw_ijlk', 'cw_ijlk', 'ct_ilk', 'TI_ilk', 'TI_eff_ilk']
 
     def __init__(self, a=[0.35, 0], deltawD=1. / np.sqrt(2), use_effective_ws=False, use_effective_ti=True,
-                 groundModel=NoGround()):
-        DeficitModel.__init__(self, groundModel=groundModel)
+                 rotorAvgModel=None, groundModel=None):
+        DeficitModel.__init__(self, rotorAvgModel=rotorAvgModel, groundModel=groundModel,
+                              use_effective_ws=use_effective_ws, use_effective_ti=use_effective_ti)
         self.a = a
         self.deltawD = deltawD
-        self.use_effective_ws = use_effective_ws
-        self.use_effective_ti = use_effective_ti
 
     def epsilon_ilk(self, ct_ilk, **_):
         return 0.34 * np.ones_like(ct_ilk)
@@ -398,17 +413,19 @@ class CarbajofuertesGaussianDeficit(ZongGaussianDeficit):
 class TurboGaussianDeficit(NiayifarGaussianDeficit):
     """Implemented similar to Ørsted's TurbOPark model (https://github.com/OrstedRD/TurbOPark)"""
 
-    args4deficit = ['WS_ilk', 'WS_eff_ilk', 'D_src_il',
-                    'dw_ijlk', 'cw_ijlk', 'ct_ilk', 'TI_ilk', 'TI_eff_ilk']
-
     def __init__(self, A=.04, cTI=[1.5, 0.8], ceps=.25, use_effective_ws=False,
-                 use_effective_ti=False, groundModel=Mirror()):
-        DeficitModel.__init__(self, groundModel=groundModel)
+                 use_effective_ti=False, rotorAvgModel=None, groundModel=Mirror()):
+        """
+        Parameters
+        ----------
+        groundModel : GroundModel or None, optional
+            if None (default), the Mirror groundModel is used
+        """
+        DeficitModel.__init__(self, rotorAvgModel=rotorAvgModel, groundModel=groundModel,
+                              use_effective_ws=use_effective_ws, use_effective_ti=use_effective_ti)
         self.A = A
         self.cTI = cTI
         self._ceps = ceps
-        self.use_effective_ws = use_effective_ws
-        self.use_effective_ti = use_effective_ti
 
     def sigma_ijlk(self, D_src_il, dw_ijlk, ct_ilk, **kwargs):
         # dimensional wake expansion
@@ -416,7 +433,7 @@ class TurboGaussianDeficit(NiayifarGaussianDeficit):
         # be adjusted to agree with the Gaussian model formulation. It is replaced by the original
         # formulation by Bastankhah
         # ----TurboNOJ identical part
-        TI_ref_ilk = (kwargs['TI_ilk'], kwargs['TI_eff_ilk'])[self.use_effective_ti]
+        TI_ref_ilk = kwargs[self.TI_key]
         c1, c2 = self.cTI
         # constants related to ambient turbulence
         alpha_ilk = c1 * TI_ref_ilk
@@ -430,7 +447,7 @@ class TurboGaussianDeficit(NiayifarGaussianDeficit):
         term3_ijlk = (term1_ijlk + 1) * alpha_ilk[:, na]
         term4_ijlk = (term2_ilk[:, na] + 1) * (alpha_ilk[:, na] +
                                                beta_ilk[:, na] * cabs(dw_ijlk) / D_src_il[:, na, :, na])
-        # ----
+
         expansion_ijlk = fac_ilk[:, na] * (term1_ijlk - term2_ilk[:, na] - np.log(term3_ijlk / term4_ijlk))
 
         return expansion_ijlk + self.epsilon_ilk(ct_ilk)[:, na] * D_src_il[:, na, :, na]
@@ -438,27 +455,26 @@ class TurboGaussianDeficit(NiayifarGaussianDeficit):
 
 def main():
     if __name__ == '__main__':
-        from py_wake.examples.data.iea37._iea37 import IEA37Site
-        from py_wake.examples.data.iea37._iea37 import IEA37_WindTurbines
         import matplotlib.pyplot as plt
         from py_wake.deficit_models.noj import NOJDeficit, TurboNOJDeficit
         from py_wake.turbulence_models.stf import STF2017TurbulenceModel
         from py_wake.superposition_models import LinearSum
         from py_wake.examples.data.hornsrev1 import Hornsrev1Site
         from py_wake.examples.data import hornsrev1
+        from py_wake.literature.iea37_case_study1 import IEA37CaseStudy1
 
         # setup site, turbines and wind farm model
-        site = IEA37Site(16)
+        wf_model = IEA37CaseStudy1(16)
+        site, windTurbines = wf_model.site, wf_model.windTurbines
+        site.default_wd = np.arange(360)
         x, y = site.initial_position.T
-        windTurbines = IEA37_WindTurbines()
 
-        wf_model = IEA37SimpleBastankhahGaussian(site, windTurbines)
-        wfm_nojturbo = PropagateDownwind(site, windTurbines, rotorAvgModel=RotorCenter(),
+        wfm_nojturbo = PropagateDownwind(site, windTurbines, rotorAvgModel=None,
                                          wake_deficitModel=TurboNOJDeficit(use_effective_ws=True,
                                                                            use_effective_ti=False),
                                          superpositionModel=LinearSum(),
                                          turbulenceModel=STF2017TurbulenceModel())
-        wfm_gauturbo = PropagateDownwind(site, windTurbines, rotorAvgModel=RotorCenter(),
+        wfm_gauturbo = PropagateDownwind(site, windTurbines, rotorAvgModel=None,
                                          wake_deficitModel=TurboGaussianDeficit(use_effective_ws=True,
                                                                                 use_effective_ti=False),
                                          superpositionModel=SquaredSum(),
@@ -471,7 +487,7 @@ def main():
         aep = sim_res.aep().sum()
 
         # plot wake map
-        fig, (ax1, ax2, ax3) = plt.subplots(1, 3, figsize=(11, 4.5), tight_layout=True)
+        (ax1, ax2, ax3) = plt.subplots(1, 3, figsize=(11, 4.5), tight_layout=True)[1]
         levels = np.arange(0, 10.5, 0.5)
         print(wf_model)
         flow_map = sim_res.flow_map(wd=30, ws=9.8)
@@ -536,14 +552,19 @@ def main():
         D_src_il = np.array([[D]])
         ct_ilk = np.array([[[.8]]])
         x, y = np.arange(20 * D), np.array([0])
+        noj_wake_width = noj.wake_radius(D_src_il=D_src_il, dw_ijlk=x.reshape((1, len(x), 1, 1)))
         noj_def = noj.calc_deficit(WS_ilk=WS_ilk, WS_eff_ilk=WS_ilk, D_src_il=D_src_il, D_dst_ijl=D_src_il,
                                    TI_ilk=TI_ilk, TI_eff_ilk=TI_eff_ilk,
                                    dw_ijlk=x.reshape((1, len(x), 1, 1)),
-                                   cw_ijlk=y.reshape((1, len(y), 1, 1)), ct_ilk=ct_ilk)
+                                   cw_ijlk=y.reshape((1, len(y), 1, 1)), ct_ilk=ct_ilk,
+                                   wake_radius_ijl=noj_wake_width[..., 0])
+        tj_wake_width = tj.wake_radius(D_src_il=D_src_il, dw_ijlk=x.reshape((1, len(x), 1, 1)), ct_ilk=ct_ilk,
+                                       TI_ilk=TI_ilk, TI_eff_ilk=TI_eff_ilk)
         tj_def = tj.calc_deficit(WS_ilk=WS_ilk, WS_eff_ilk=WS_ilk, D_src_il=D_src_il, D_dst_ijl=D_src_il,
                                  TI_ilk=TI_ilk, TI_eff_ilk=TI_eff_ilk,
                                  dw_ijlk=x.reshape((1, len(x), 1, 1)),
-                                 cw_ijlk=y.reshape((1, len(y), 1, 1)), ct_ilk=ct_ilk)
+                                 cw_ijlk=y.reshape((1, len(y), 1, 1)), ct_ilk=ct_ilk,
+                                 wake_radius_ijlk=tj_wake_width)
         tjg_def = tjg.calc_deficit(WS_ilk=WS_ilk, WS_eff_ilk=WS_ilk, D_src_il=D_src_il,
                                    TI_ilk=TI_ilk, TI_eff_ilk=TI_eff_ilk,
                                    dw_ijlk=x.reshape((1, len(x), 1, 1)),
