@@ -1,10 +1,9 @@
-import numpy as np
+from py_wake import np
 from numpy import newaxis as na
 from py_wake.deficit_models.selfsimilarity import SelfSimilarityDeficit2020
 from py_wake.deficit_models.vortexdipole import VortexDipole
 from py_wake.deficit_models import DeficitModel
 from py_wake.deficit_models import BlockageDeficitModel
-from py_wake.ground_models.ground_models import NoGround
 from py_wake.utils.gradients import hypot
 
 
@@ -27,16 +26,22 @@ class HybridInduction(BlockageDeficitModel):
             https://doi.org/10.1002/we.2546
     """
 
-    args4deficit = ['WS_ilk', 'D_src_il', 'dw_ijlk', 'cw_ijlk', 'ct_ilk']
-
     def __init__(self, switch_radius=6.,
-                 near_rotor=SelfSimilarityDeficit2020(), far_field=VortexDipole(), superpositionModel=None,
-                 groundModel=NoGround(), upstream_only=False):
-        DeficitModel.__init__(self, groundModel=groundModel)
-        BlockageDeficitModel.__init__(self, upstream_only=upstream_only, superpositionModel=superpositionModel)
+                 near_rotor=None, far_field=None, superpositionModel=None,
+                 rotorAvgModel=None, groundModel=None, upstream_only=False):
+        """
+        Parameters
+        ----------
+        near_rotor : BlockageDeficitModel or None
+            If None (default), the SelfSimilarityDeficit2020 will be used
+        far_field : BlockageDeficitModel or None
+            If None (default), the VortexDipole will be used
+        """
+        BlockageDeficitModel.__init__(self, upstream_only=upstream_only, superpositionModel=superpositionModel,
+                                      rotorAvgModel=rotorAvgModel, groundModel=groundModel)
         self.switch_radius = switch_radius
-        self.near_rotor = near_rotor
-        self.far_field = far_field
+        self.near_rotor = near_rotor or SelfSimilarityDeficit2020()
+        self.far_field = far_field or VortexDipole()
 
     def calc_deficit(self, WS_ilk, D_src_il, dw_ijlk, cw_ijlk, ct_ilk, **_):
 
@@ -76,9 +81,9 @@ def main():
         hi = HybridInduction()
 
         plt.figure()
-        noj_hi = All2AllIterative(site, windTurbines, wake_deficitModel=NoWakeDeficit(),
-                                  superpositionModel=LinearSum(), blockage_deficitModel=hi)
-        flow_map = noj_hi(x=[0], y=[0], wd=[270], ws=[10]).flow_map()
+        wfm = All2AllIterative(site, windTurbines, wake_deficitModel=NoWakeDeficit(),
+                               superpositionModel=LinearSum(), blockage_deficitModel=hi)
+        flow_map = wfm(x=[0], y=[0], wd=[270], ws=[10]).flow_map()
         clevels = np.array([.6, .7, .8, .9, .95, .98, .99, .995, .998, .999, 1., 1.01, 1.02]) * 10.
         flow_map.plot_wake_map(levels=clevels)
         plt.title('Vortex Dipole (far-field) + Self-Similar (near-rotor)')
@@ -87,14 +92,14 @@ def main():
         plt.show()
 
         # run wind farm simulation
-        sim_res = noj_hi(x, y, wd=[0, 30, 45, 60, 90], ws=[5, 10, 15])
+        sim_res = wfm(x, y, wd=[0, 30, 45, 60, 90], ws=[5, 10, 15])
 
         # calculate AEP
         aep = sim_res.aep().sum()
 
         # plot wake map
         plt.figure()
-        print(noj_hi)
+        print(wfm)
         flow_map = sim_res.flow_map(wd=0, ws=10)
         flow_map.plot_wake_map(levels=clevels, plot_colorbar=False)
         plt.title('Vortex Dipole (far-field) + Self-Similar (near-rotor), AEP: %.3f GWh' % aep)
