@@ -1,10 +1,10 @@
-import numpy as np
+from py_wake import np
 from numpy import newaxis as na
 from py_wake.deficit_models import DeficitModel
 from py_wake.deficit_models import BlockageDeficitModel
-from py_wake.ground_models.ground_models import NoGround
 from py_wake.utils.gradients import hypot
 from py_wake.deficit_models.utils import a0
+import warnings
 
 
 class RankineHalfBody(BlockageDeficitModel):
@@ -17,12 +17,10 @@ class RankineHalfBody(BlockageDeficitModel):
             induction and wind farm blockage - Technical Paper, Frazer-Nash Consultancy, 2019
     """
 
-    args4deficit = ['WS_ilk', 'D_src_il', 'dw_ijlk', 'cw_ijlk', 'ct_ilk']
-
-    def __init__(self, limiter=1e-10, exclude_wake=True, superpositionModel=None, groundModel=NoGround(),
-                 upstream_only=False):
-        DeficitModel.__init__(self, groundModel=groundModel)
-        BlockageDeficitModel.__init__(self, upstream_only=upstream_only, superpositionModel=superpositionModel)
+    def __init__(self, limiter=1e-10, exclude_wake=True, superpositionModel=None,
+                 rotorAvgModel=None, groundModel=None, upstream_only=False):
+        BlockageDeficitModel.__init__(self, upstream_only=upstream_only, superpositionModel=superpositionModel,
+                                      rotorAvgModel=rotorAvgModel, groundModel=groundModel)
         # limiter to avoid singularities
         self.limiter = limiter
         # if used in a wind farm simulation, set deficit in wake region to
@@ -33,7 +31,10 @@ class RankineHalfBody(BlockageDeficitModel):
         """
         Find all points lying outside Rankine Half Body, stagnation line given on p.3
         """
-        cos_ijlk = dw_ijlk / r_ijlk
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', r'invalid value encountered in true_divide')
+            warnings.filterwarnings('ignore', r'invalid value encountered in divide')
+            cos_ijlk = dw_ijlk / r_ijlk
         # avoid division by zero
         f_ilk = a0_ilk * R_il[:, :, na]
         f_ilk = np.where(f_ilk == 0., np.inf, f_ilk)
