@@ -1,5 +1,5 @@
 from py_wake.site.distance import StraightDistance
-import numpy as np
+from py_wake import np
 from numpy import newaxis as na
 import matplotlib.pyplot as plt
 from py_wake.examples.data.ParqueFicticio._parque_ficticio import ParqueFicticioSite
@@ -22,21 +22,27 @@ class JITStreamlineDistance(StraightDistance):
         step_size : int for float
             Size of linear streamline steps
         """
+        StraightDistance.__init__(self, wind_direction='wd')
         self.vectorField = vectorField
         self.step_size = step_size
 
-    def __call__(self, wd_l, WD_il, src_idx=slice(None), dst_idx=slice(None)):
-        start_points_m = np.array([self.src_x_i[src_idx], self.src_y_i[src_idx], self.src_h_i[src_idx]]).T
+    def __call__(self, wd_l, WD_ilk, src_idx=slice(None), dst_idx=slice(None)):
+        assert self.src_x_ilk.shape[1:] == (1, 1), 'JITStreamlineDistance does not support flowcase dependent positions'
+        start_points_m = np.array([self.src_x_ilk[src_idx], self.src_y_ilk[src_idx],
+                                   self.src_h_ilk[src_idx]])[:, :, 0, 0].T
 
-        if len(np.shape(WD_il)) == 1:
-            dw_jl, hcw_jl, dh_jl = StraightDistance.__call__(self, WD_il=wd_l, src_idx=src_idx, dst_idx=dst_idx)
+        if len(np.shape(dst_idx)) == 2:
+            # dst_idx depends on wind direction
+            dw_jl, hcw_jl, dh_jl = [v[0, :, :, 0] for v in StraightDistance.__call__(self, wd_l=wd_l,
+                                                                                     src_idx=src_idx, dst_idx=dst_idx)]
             dw_mj, hcw_mj, dh_mj = [np.moveaxis(v, 0, 1) for v in [dw_jl, hcw_jl, dh_jl]]
             wd_m = wd_l
         else:
-            # WD_il
-            dw_ijl, hcw_ijl, dh_ijl = StraightDistance.__call__(self, WD_il=wd_l[na], src_idx=src_idx, dst_idx=dst_idx)
-            I, J, L = dw_ijl.shape
-            dw_mj, hcw_mj, dh_mj = [np.moveaxis(v, 1, 2).reshape(I * L, J) for v in [dw_ijl, hcw_ijl, dh_ijl]]
+            # dst_idx independent of wind direction
+            dw_ijlk, hcw_ijlk, dh_ijlk = StraightDistance.__call__(self, wd_l=wd_l,
+                                                                   src_idx=src_idx, dst_idx=dst_idx)
+            I, J, L, K = dw_ijlk.shape
+            dw_mj, hcw_mj, dh_mj = [np.moveaxis(v, 1, 2).reshape(I * L, J) for v in [dw_ijlk, hcw_ijlk, dh_ijlk]]
             wd_m = np.tile(wd_l, I)
             start_points_m = np.repeat(start_points_m, L, 0)
 
@@ -57,10 +63,10 @@ class JITStreamlineDistance(StraightDistance):
             dh_mj[m, dw] += np.interp(dw_j[dw], dw_s, dh_s)
             dw_mj[m, dw] = np.interp(dw_j[dw], dw_s, length_s)
 
-        if len(np.shape(WD_il)) == 1:
-            return [np.moveaxis(v, 0, 1) for v in [dw_mj, hcw_mj, dh_mj]]
+        if len(np.shape(dst_idx)) == 2:
+            return [np.moveaxis(v, 0, 1)[na, :, :, na] for v in [dw_mj, hcw_mj, dh_mj]]
         else:
-            return [v.reshape((I, J, L)) for v in [dw_mj, hcw_mj, dh_mj]]
+            return [v.reshape((I, J, L, K)) for v in [dw_mj, hcw_mj, dh_mj]]
 
 
 def main():
