@@ -1,4 +1,4 @@
-import numpy as np
+from py_wake import np
 import xarray as xr
 import pickle
 import os
@@ -8,6 +8,7 @@ import re
 import copy
 from py_wake.site.distance import TerrainFollowingDistance
 from py_wake.site.xrsite import XRSite
+from numpy import newaxis as na
 
 
 class WaspGridSite(XRSite):
@@ -36,13 +37,16 @@ class WaspGridSite(XRSite):
         super().__init__(ds, distance=distance)
 
     def _local_wind(self, localWind, ws_bins=None):
-        lw = super()._local_wind(localWind.copy(), ws_bins)
+        lw = super()._local_wind(localWind, ws_bins)
 
         # ti is assumed to be the turbulence intensity given by CFD
         # (expected value of TI at 15m/s). The Normal Turbulence model
         # is used to calculate TI at different wind speed,
         # see footnote 4 at page 24 of IEC 61400-1 (2005)
-        lw['TI'] = self.interp(self.ds.ti15ms, lw.coords) * (.75 + 3.8 / lw.ws)
+        if 'time' in lw.coords:
+            lw['TI_ilk'] = self.interp(self.ds.ti15ms, lw) * (.75 + 3.8 / lw.ws)[na, :, na]
+        else:
+            lw['TI_ilk'] = self.interp(self.ds.ti15ms, lw) * (.75 + 3.8 / lw.ws)
         return lw
 
     @classmethod
@@ -269,7 +273,7 @@ def main():
 
         # plot shear
         z = np.arange(35, 200, 1)
-        u_z = site.local_wind([x[i]] * len(z), y_i=[y[i]] * len(z), h_i=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
+        u_z = site.local_wind(x=[x[i]] * len(z), y=[y[i]] * len(z), h=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
         plt.figure()
         plt.plot(u_z, z)
         plt.xlabel('Wind speed [m/s]')
