@@ -1,7 +1,7 @@
 from pathlib import Path
 
 import matplotlib.pyplot as plt
-import numpy as np
+from py_wake import np
 from py_wake.deficit_models.fuga import FugaYawDeficit
 from py_wake.flow_map import XYGrid
 from py_wake.site.xrsite import UniformSite
@@ -11,8 +11,7 @@ from py_wake.wind_turbines._wind_turbines import WindTurbine
 from py_wake.wind_turbines.power_ct_functions import PowerCtTabular
 from py_wake.tests import npt
 from py_wake.deflection_models.fuga_deflection import FugaDeflection
-from scipy.interpolate.fitpack2 import InterpolatedUnivariateSpline
-from py_wake.examples.data.hornsrev1 import V80, Hornsrev1Site
+from scipy.interpolate import InterpolatedUnivariateSpline
 
 
 def test_fuga_deflection_vs_notebook():
@@ -20,10 +19,10 @@ def test_fuga_deflection_vs_notebook():
     p = Path(tfp) / "fuga/v80_deflection_x.csv"
     x, notebook_deflection = np.array([v.split(",") for v in p.read_text().strip().split("\n")], dtype=float).T
 
-    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00'
-    fuga_deflection = -FugaDeflection(path).calc_deflection(dw_ijl=np.reshape(x, (1, 41, 1)),
-                                                            hcw_ijl=np.reshape(x * 0, (1, 41, 1)),
-                                                            dh_ijl=np.reshape(x * 0, (1, 41, 1)),
+    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00.nc'
+    fuga_deflection = -FugaDeflection(path).calc_deflection(dw_ijlk=np.reshape(x, (1, 41, 1, 1)),
+                                                            hcw_ijlk=np.reshape(x * 0, (1, 41, 1, 1)),
+                                                            dh_ijlk=np.reshape(x * 0, (1, 41, 1, 1)),
                                                             WS_ilk=np.array([[[9.5]]]),
                                                             WS_eff_ilk=np.array([[[9.5]]]),
                                                             yaw_ilk=np.array([[[17.4493]]]),
@@ -47,7 +46,7 @@ def test_fuga_wake_center_vs_notebook():
     powerCtFunction = PowerCtTabular([0, 100], [0, 0], 'w', [0.850877, 0.850877])
     wt = WindTurbine(name='', diameter=80, hub_height=70, powerCtFunction=powerCtFunction)
 
-    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00'
+    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00.nc'
     site = UniformSite([1, 0, 0, 0], ti=0.075)
 
     wfm = PropagateDownwind(
@@ -80,7 +79,7 @@ def test_fuga_deflection_time_series_gradient_evaluation():
     powerCtFunction = PowerCtTabular([0, 100], [0, 0], 'w', [0.850877, 0.850877])
     wt = WindTurbine(name='', diameter=80, hub_height=70, powerCtFunction=powerCtFunction)
 
-    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00'
+    path = tfp + 'fuga/2MW/Z0=0.00001000Zi=00400Zeta0=0.00E+00.nc'
     site = UniformSite([1, 0, 0, 0], ti=0.075)
 
     wfm = PropagateDownwind(
