@@ -1,4 +1,4 @@
-import numpy as np
+from py_wake import np
 import matplotlib.pyplot as plt
 from py_wake.deficit_models.gaussian import BastankhahGaussian, ZongGaussian, ZongGaussianDeficit
 from py_wake.deflection_models import GCLHillDeflection
@@ -47,7 +47,7 @@ def test_torque_result():
         plt.figure(figsize=(12, 3))
 
         grid = XYGrid(x=np.linspace(-2 * D, D * 10, 100), y=np.linspace(-1.5 * D, 1.5 * D, 100))
-        fm = wfm(x, y, yaw=yaw, wd=270, ws=ws).flow_map(grid)
+        fm = wfm(x, y, yaw=yaw, tilt=0, wd=270, ws=ws).flow_map(grid)
         fm.plot_wake_map(normalize_with=D)
         center_line = fm.min_WS_eff()
         plt.title(f'Yaw {yaw}deg')
@@ -74,11 +74,11 @@ def test_N():
     def deflection_20d(N):
         wfm = ZongGaussian(site, wt, deflectionModel=GCLHillDeflection(N=N),
                            turbulenceModel=CrespoHernandez())
-        fm = wfm(x, y, yaw=30, wd=270, ws=10).flow_map(grid)
+        fm = wfm(x, y, yaw=30, tilt=0, wd=270, ws=10).flow_map(grid)
         return fm.min_WS_eff().values[-1]
 
     N_lst = [10, 20, 100]
-    res = [timeit(deflection_20d, min_runs=10)(N) for N in N_lst]
+    res = [timeit(deflection_20d, min_runs=1)(N) for N in N_lst]
     plt.plot(N_lst, [d for d, _ in res])
     plt.ylabel('Deflection 20D downstream [m]')
     plt.xlabel('N')
@@ -104,5 +104,5 @@ def test_wake_deficitModel_input():
                               turbulenceModel=CrespoHernandez())
 
     grid = XYGrid(x=np.linspace(10, D * 10, 100), y=np.linspace(-1.5 * D, 1.5 * D, 100))
-    cl1, cl2 = [wfm(x, y, yaw=30, wd=270, ws=10).flow_map(grid).min_WS_eff() for wfm in [wfm1, wfm2]]
+    cl1, cl2 = [wfm(x, y, yaw=30, tilt=0, wd=270, ws=10).flow_map(grid).min_WS_eff() for wfm in [wfm1, wfm2]]
     npt.assert_array_almost_equal(cl1, cl2, 3)
