@@ -1,6 +1,6 @@
 import os
 import pytest
-import numpy as np
+from py_wake import np
 import matplotlib.pyplot as plt
 from py_wake.tests import npt
 from py_wake.site._site import UniformWeibullSite, UniformSite
@@ -36,24 +36,25 @@ def test_local_wind(site):
     x_i = y_i = np.arange(5)
     wdir_lst = np.arange(0, 360, 90)
     wsp_lst = np.arange(3, 6)
-    lw = site.local_wind(x_i=x_i, y_i=y_i, h_i=50, wd=wdir_lst, ws=wsp_lst)
+    lw = site.local_wind(x=x_i, y=y_i, h=[50], wd=wdir_lst, ws=wsp_lst)
     npt.assert_array_equal(lw.WS_ilk.shape, (1, 4, 3))
 
-    lw = site.local_wind(x_i=x_i, y_i=y_i, h_i=50)
+    lw = site.local_wind(x=x_i, y=y_i, h=x_i * 0 + 50)
     npt.assert_array_equal(lw.WS_ilk.shape, (1, 360, 23))
+    assert lw.WS.attrs['description'] == 'Local free-stream wind speed [m/s]'
 
     # check probability local_wind()[-1]
-    npt.assert_equal(site.local_wind(x_i=x_i, y_i=y_i, h_i=50, wd=[0], ws=[10], wd_bin_size=1).P_ilk,
-                     site.local_wind(x_i=x_i, y_i=y_i, h_i=50, wd=[0], ws=[10], wd_bin_size=2).P_ilk / 2)
-    npt.assert_almost_equal(site.local_wind(x_i=x_i, y_i=y_i, h_i=50, wd=[0], ws=[9, 10, 11]).P_ilk.sum((1, 2)),
-                            site.local_wind(x_i=x_i, y_i=y_i, h_i=50, wd=[0], ws=[10], ws_bins=3).P_ilk[:, 0, 0], 5)
+    npt.assert_equal(site.local_wind(x=x_i, y=y_i, h=50, wd=[0], ws=[10], wd_bin_size=1).P_ilk,
+                     site.local_wind(x=x_i, y=y_i, h=50, wd=[0], ws=[10], wd_bin_size=2).P_ilk / 2)
+    npt.assert_almost_equal(site.local_wind(x=x_i, y=y_i, h=50, wd=[0], ws=[9, 10, 11]).P_ilk.sum((1, 2)),
+                            site.local_wind(x=x_i, y=y_i, h=50, wd=[0], ws=[10], ws_bins=3).P_ilk[:, 0, 0], 5)
 
     z = np.arange(1, 100)
     zero = [0] * len(z)
 
-    ws = site.local_wind(x_i=zero, y_i=zero, h_i=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
+    ws = site.local_wind(x=zero, y=zero, h=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
     site2 = UniformWeibullSite(f, A, k, ti, shear=PowerShear(70, alpha=np.zeros_like(f) + .3))
-    ws70 = site2.local_wind(x_i=zero, y_i=zero, h_i=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
+    ws70 = site2.local_wind(x=zero, y=zero, h=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
     if 0:
         plt.plot(ws, z)
         plt.plot(ws70, z)
@@ -210,20 +211,18 @@ def test_plot_ws_distribution_iea37():
 
 
 def test_iea37_distances():
-    from py_wake.examples.data.iea37 import IEA37Site
-
     n_wt = 16  # must be 9, 16, 36, 64
     site = IEA37Site(n_wt)
     x, y = site.initial_position.T
-    lw = site.local_wind(x_i=x, y_i=y,
+    lw = site.local_wind(x=x, y=y,
                          wd=site.default_wd,
                          ws=site.default_ws)
     site.distance.setup(x, y, np.zeros_like(x))
-    dw_iil, hcw_iil, _ = site.wt2wt_distances(WD_il=lw.WD_ilk.mean(2))
+    dw_iil, hcw_iil, _ = site.wt2wt_distances(wd_l=lw.wd)
     # Wind direction.
     wdir = np.rad2deg(np.arctan2(hcw_iil, dw_iil))
     npt.assert_allclose(
-        wdir[:, 0, 0],
+        wdir[:, 0, 0, 0],
         [180, -90, -18, 54, 126, -162, -90, -54, -18, 18, 54, 90, 126, 162, -162, -126],
         atol=1e-4)
 
