@@ -1,4 +1,4 @@
-import numpy as np
+from py_wake import np
 from numpy import newaxis as na
 from py_wake.tests import npt
 import pytest
@@ -7,13 +7,14 @@ from py_wake.site.wasp_grid_site import WaspGridSite
 import os
 import time
 from py_wake.tests.test_files.wasp_grid_site import one_layer
-from py_wake.site.distance import TerrainFollowingDistance, StraightDistance, TerrainFollowingDistance2
+from py_wake.site.distance import TerrainFollowingDistance, StraightDistance
 import math
 from py_wake import NOJ
-from py_wake.wind_turbines import OneTypeWindTurbines
 import matplotlib.pyplot as plt
 from py_wake.site.xrsite import XRSite
 import shutil
+from py_wake.wind_turbines._wind_turbines import WindTurbine
+from py_wake.wind_turbines.power_ct_functions import PowerCtTabular
 
 
 @pytest.fixture(autouse=True)
@@ -32,13 +33,6 @@ def site():
     return ParqueFicticioSite()
 
 
-@pytest.fixture
-def site2():
-    site = ParqueFicticioSite(distance=TerrainFollowingDistance2())
-    x, y = site.initial_position.T
-    return site, x, y
-
-
 def test_WaspGridSiteDistanceClass(site):
     wgs = XRSite(site.ds, distance=TerrainFollowingDistance(distance_resolution=2000))
     assert wgs.distance.distance_resolution == 2000
@@ -52,15 +46,25 @@ def test_local_wind(site):
     h_i = x_i * 0 + 70
     wdir_lst = np.arange(0, 360, 90)
     wsp_lst = np.arange(3, 6)
-    WS_ilk = site.local_wind(x_i=x_i, y_i=y_i, h_i=h_i, wd=wdir_lst, ws=wsp_lst).WS_ilk
+    WS_ilk = site.local_wind(x=x_i, y=y_i, h=h_i, wd=wdir_lst, ws=wsp_lst).WS_ilk
     npt.assert_array_equal(WS_ilk.shape, (8, 4, 3))
 
-    WS_ilk = site.local_wind(x_i=x_i, y_i=y_i, h_i=h_i).WS_ilk
+    WS_ilk = site.local_wind(x=x_i, y=y_i, h=h_i).WS_ilk
     npt.assert_array_equal(WS_ilk.shape, (8, 360, 23))
 
     # check probability local_wind()[-1]
-    npt.assert_almost_equal(site.local_wind(x_i=x_i, y_i=y_i, h_i=h_i, wd=[0], ws=[10], wd_bin_size=1).P_ilk,
-                            site.local_wind(x_i=x_i, y_i=y_i, h_i=h_i, wd=[0], ws=[10], wd_bin_size=2).P_ilk / 2, 6)
+    npt.assert_almost_equal(site.local_wind(x=x_i, y=y_i, h=h_i, wd=[0], ws=[10], wd_bin_size=1).P_ilk,
+                            site.local_wind(x=x_i, y=y_i, h=h_i, wd=[0], ws=[10], wd_bin_size=2).P_ilk / 2, 6)
+
+
+def test_local_wind_time(site):
+    x_i, y_i = site.initial_position.T
+    wdir_lst = [0, 1, 2, 1, 0]
+    wsp_lst = [9, 10, 9, 10, 11]
+    lw = site.local_wind(x_i, y_i, h=100, wd=wdir_lst, ws=wsp_lst, time=True)
+    assert lw.WS_ilk.shape == (8, 5, 1)
+    assert lw.WD_ilk.shape == (8, 5, 1)
+    assert lw.TI_ilk.shape == (8, 5, 1)
 
 
 def test_shear(site):
@@ -68,7 +72,7 @@ def test_shear(site):
     x = [262878.0001] * 3
     y = [6504714.0001] * 3
     z = [30, 115, 200]
-    ws = site.local_wind(x_i=x, y_i=y, h_i=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
+    ws = site.local_wind(x=x, y=y, h=z, wd=[0], ws=[10]).WS_ilk[:, 0, 0]
 
     if 0:
         plt.plot(ws, z, '.-')
@@ -132,12 +136,12 @@ def test_wasp_resources_grid_point(site):
                      2744., 2747., 2748., 2748., 2750., 2750., 2750., 2750., 2750., 2750.])
     wt_ct = np.array([0, 0.871, 0.853, 0.841, 0.841, 0.833, 0.797, 0.743, 0.635, 0.543, 0.424,
                       0.324, 0.258, 0.21, 0.175, 0.147, 0.126, 0.109, 0.095, 0.083, 0.074, 0.065, 0.059])
-    wt = OneTypeWindTurbines.from_tabular(name="NEG-Micon 2750/92 (2750 kW)", diameter=92, hub_height=70,
-                                          ws=wt_u, ct=wt_ct, power=wt_p, power_unit='kw')
+    wt = WindTurbine(name="NEG-Micon 2750/92 (2750 kW)", diameter=92, hub_height=70,
+                     powerCtFunction=PowerCtTabular(ws=wt_u, power=wt_p, power_unit='kw', ct=wt_ct))
 
     lw = site.local_wind(x, y, 30, wd=range(0, 360, 30))
     A_lst, k_lst, f_lst, spd_lst, orog_trn_lst, flow_inc_lst, ti15ms_lst = [
-        site.interp(site.ds[n], lw.coords).sel(i=0).values
+        site.interp(site.ds[n], lw)[0, :, 0]
         for n in ['Weibull_A', 'Weibull_k', 'Sector_frequency', 'Speedup', 'Turning', 'flow_inc', 'ti15ms']]
     pdf_lst = [lambda x, A=A, k=k: k / A * (x / A)**(k - 1) * np.exp(-(x / A)**k) * (x[1] - x[0])
                for A, k in zip(A_lst, k_lst)]
@@ -187,42 +191,21 @@ def test_wasp_resources_grid_point(site):
     npt.assert_almost_equal(AEP_ilk.sum(), wasp_aep_no_density_correction_total, 3)
 
 
-@pytest.mark.parametrize('site,dw_ref', [
-    (ParqueFicticioSite(distance=TerrainFollowingDistance2()),
-     [0., 207.3842238, 484.3998264, 726.7130743, 1039.148129, 1263.1335982, 1490.3841602, 1840.6508086]),
-    (ParqueFicticioSite(distance=TerrainFollowingDistance()),
+@pytest.mark.parametrize('distance,dw_ref', [
+    (TerrainFollowingDistance(),
      [0, 209.803579, 480.8335365, 715.6003233, 1026.9476322, 1249.5510034, 1475.1467251, 1824.1317343]),
-    (ParqueFicticioSite(distance=StraightDistance()),
-     [-0, 207, 477, 710, 1016, 1236, 1456, 1799])])
-def test_distances(site, dw_ref):
+    (StraightDistance(), [-0, 207, 477, 710, 1016, 1236, 1456, 1799])])
+def test_distances(distance, dw_ref):
+    site = ParqueFicticioSite(distance)
     x, y = site.initial_position.T
-    site.distance.setup(src_x_i=x, src_y_i=y, src_h_i=np.array([70]),
+    site.distance.setup(src_x_ilk=x, src_y_ilk=y, src_h_ilk=np.array([70]),
                         dst_xyh_j=(x, y, np.array([70])))
-    dw_ijl, cw_ijl, dh_ijl = site.distance(WD_il=np.array([[0]]))
-    npt.assert_almost_equal(dw_ijl[0, :, 0], dw_ref)
+    dw_ijlk, cw_ijlk, dh_ijlk = site.distance(wd_l=[0])
+    npt.assert_almost_equal(dw_ijlk[0, :, 0, 0], dw_ref)
 
     cw_ref = [236.1, 0., -131.1, -167.8, -204.5, -131.1, -131.1, -45.4]
-    npt.assert_almost_equal(cw_ijl[:, 1, 0], cw_ref)
-    npt.assert_almost_equal(dh_ijl, np.zeros_like(dh_ijl))
-
-
-def test_distances_different_points(site2):
-    site, x, y = site2
-    with pytest.raises(NotImplementedError):
-        site.distance.setup(src_x_i=x, src_y_i=y, src_h_i=np.array([70]),
-                            dst_xyh_j=(x[1:], y[1:], np.array([70])))
-        site.distance(WD_il=np.array([[0]]))
-
-
-# def test_distances_wd_shape():
-#     site = ParqueFicticioSite(distance=TerrainFollowingDistance2())
-#     x, y = site.initial_position.T
-#     dw_ijl, cw_ijl, dh_ijl, dwo = site.distances(src_x_i=x, src_y_i=y, src_h_i=np.array([70]),
-#                                                  dst_x_j=x, dst_y_j=y, dst_h_j=np.array([70]),
-#                                                  wd_il=np.ones((len(x), 1)) * 180)
-#     npt.assert_almost_equal(dw_ijl[0, :, 0], np.array([0., -207., -477., -710., -1016., -1236., -1456., -1799.]))
-#     npt.assert_almost_equal(cw_ijl[:, 1, 0], np.array([-236.1, 0., 131.1, 167.8, 204.5, 131.1, 131.1, 45.4]))
-#     npt.assert_almost_equal(dh_ijl, np.zeros_like(dh_ijl))
+    npt.assert_almost_equal(cw_ijlk[:, 1, 0, 0], cw_ref)
+    npt.assert_almost_equal(dh_ijlk, np.zeros_like(dh_ijlk))
 
 
 def test_speed_up_using_pickle():
@@ -347,8 +330,8 @@ def test_additional_input():
     h = 70 * np.ones_like(x)
 
     lw = site.local_wind(x, y, h)
-    ws_mean = site.interp(site.ds.ws_mean, lw.coords)
-    npt.assert_array_almost_equal(ws_mean[0, :50],
+    ws_mean = site.interp(site.ds.ws_mean, lw)
+    npt.assert_array_almost_equal(ws_mean[0, :50, 0],
                                   np.array([4.77080802, 4.77216214, 4.77351626, 4.77487037, 4.77622449,
                                             4.77757861, 4.77893273, 4.78028685, 4.78164097, 4.78299508,
                                             4.7843492, 4.78570332, 4.78705744, 4.78841156, 4.78976567,
@@ -359,7 +342,3 @@ def test_additional_input():
                                             5.10998066, 5.16969047, 5.22940029, 5.28911011, 5.34881993,
                                             5.40852975, 5.46823957, 5.52794939, 5.5876592, 5.64736902,
                                             5.70707884, 5.76678866, 5.82649848, 5.8862083, 5.94591812]))
-
-
-if __name__ == '__main__':
-    test_wasp_resources_grid_point(ParqueFicticioSite())
