@@ -2,7 +2,7 @@ from numpy import newaxis as na
 import pytest
 import xarray as xr
 import matplotlib.pyplot as plt
-import numpy as np
+from py_wake import np
 from py_wake.examples.data import hornsrev1
 from py_wake.tests import npt
 from py_wake.wind_turbines.power_ct_functions import CubePowerSimpleCt, DensityScale, \
@@ -294,7 +294,7 @@ def test_unused_input():
     ri, oi = wfm.windTurbines.function_inputs
     npt.assert_array_equal(ri, [])
     npt.assert_array_equal(oi, ['Air_density', 'boost', 'tilt', 'yaw'])
-    with pytest.raises(TypeError, match=r"got unexpected keyword argument\(s\): 'mode'"):
+    with pytest.raises(ValueError, match=r"WindFarmModel an got unexpected keyword argument: 'mode'"):
         wfm([0], [0], boost=1, mode=1)
 
 
@@ -440,8 +440,8 @@ def test_gradients(case, wt, dpdu_ref, dctdu_ref, grad_method):
 
     ws_lst = np.arange(2, 25, .1)
     kwargs = {k: 1 for k in wt.function_inputs[0]}
-    dpdu_lst = grad_method(wt.power)(ws_pts, **kwargs)
-    dctdu_lst = grad_method(wt.ct)(ws_pts, **kwargs)
+    dpdu_lst = grad_method(wt.power, vector_interdependence=False)(ws_pts, **kwargs)
+    dctdu_lst = grad_method(wt.ct, vector_interdependence=False)(ws_pts, **kwargs)
 
     if 0:
         gradients.color_dict = {'power': 'b', 'ct': 'r'}
@@ -463,7 +463,7 @@ def test_gradients(case, wt, dpdu_ref, dctdu_ref, grad_method):
 if __name__ == '__main__':
     x = np.linspace(0, 2 * np.pi, 100)
     import matplotlib.pyplot as plt
-    import numpy as np
+    from py_wake import np
     plt.plot(x, np.sin(x) / x)
     plt.plot(x, np.sin(x))
     plt.show()
