@@ -1,13 +1,12 @@
-import numpy as np
-from scipy.interpolate import RegularGridInterpolator
+from py_wake import np
+
 from abc import abstractmethod, ABC
-from autograd.core import defvjp, primitive
 from py_wake.wind_turbines.wind_turbine_functions import WindTurbineFunction, FunctionSurrogates,\
     WindTurbineFunctionList
 from py_wake.utils.check_input import check_input
 from py_wake.utils.model_utils import check_model, fix_shape
 from py_wake.utils import gradients
-from py_wake.utils.gradients import PchipInterpolator, UnivariateSpline, set_vjp
+from py_wake.utils.gradients import PchipInterpolator, UnivariateSpline
 from py_wake.utils.grid_interpolator import GridInterpolator
 
 
@@ -103,19 +102,16 @@ class SimpleYawModel(AdditionalModel):
             output_keys=['power', 'ct'])
 
     def __call__(self, f, ws, yaw=None, tilt=None, **kwargs):
-        if yaw is not None or tilt is not None:
-            co = 1
-            if yaw is not None:
-                co *= np.cos(gradients.deg2rad(fix_shape(yaw, ws, True)))
-            if tilt is not None:
-                co *= np.cos(gradients.deg2rad(fix_shape(tilt, ws, True)))
-            power_ct_arr = f(ws * co, **kwargs)  # calculate for reduced ws (ws projection on rotor)
-            if kwargs['run_only'] == 1:  # ct
-                # multiply ct by cos(yaw)**2 to compensate for reduced thrust
-                return power_ct_arr * co**2
-            return power_ct_arr
-        else:
-            return f(ws, **kwargs)
+        co = 1
+        if yaw is not None:
+            co *= np.cos(gradients.deg2rad(fix_shape(yaw, ws, True)))
+        if tilt is not None:
+            co *= np.cos(gradients.deg2rad(fix_shape(tilt, ws, True)))
+        power_ct_arr = f(ws * co, **kwargs)  # calculate for reduced ws (ws projection on rotor)
+        if kwargs['run_only'] == 1:  # ct
+            # multiply ct by cos(yaw)**2 to compensate for reduced thrust
+            return power_ct_arr * co**2
+        return power_ct_arr
 
 
 class DensityScale(AdditionalModel):
@@ -134,6 +130,21 @@ class DensityScale(AdditionalModel):
         return power_ct_arr
 
 
+class DensityCompensation(AdditionalModel):
+    """Scales the wind speed with density before calculating power and ct"""
+
+    def __init__(self, air_density_ref):
+        AdditionalModel.__init__(self, input_keys=['ws', 'Air_density'], optional_inputs=['Air_density'],
+                                 output_keys=['power', 'ct'])
+        self.air_density_ref = air_density_ref
+
+    def __call__(self, f, ws, Air_density=None, **kwargs):
+        if Air_density is not None:
+            # cannot used *= if Air_density is complex
+            ws = ws * (fix_shape(Air_density, ws, True) / self.air_density_ref)**(1 / 3)
+        return np.asarray(f(ws, **kwargs))
+
+
 default_additional_models = [SimpleYawModel(), DensityScale(1.225)]
 
 
@@ -200,7 +211,7 @@ class PowerCtTabular(PowerCtFunction):
             see ws_cutin and ws_cutout
         ct_idle : number, optional
             see ws_cutin and ws_cutout
-        method : {'linear', 'phip','spline}
+        method : {'linear', 'pchip','spline}
             Interpolation method:\n
             - linear: fast, discontinous gradients\n
             - pchip: smooth\n
@@ -366,10 +377,11 @@ class PowerCtXr(PowerCtNDTabular):
             list of additional models.
         """
         assert method == 'linear'
-        assert 'power' in ds
-        assert 'ct' in ds
+        keys = {k.lower(): k for k in ds}
+        assert 'power' in keys
+        assert 'ct' in keys
         assert 'ws' in ds.dims
-        ds = ds[['power', 'ct']]
+        ds = ds[[keys['power'], keys['ct']]]
         power_arr, ct_arr = ds.to_array()
 
         if list(power_arr.dims).index('ws') > 0:
@@ -380,7 +392,19 @@ class PowerCtXr(PowerCtNDTabular):
                                   ct_arr.values, additional_models=additional_models)
 
 
-class CubePowerSimpleCt(PowerCtFunction):
+class PowerCtFunctions(PowerCtFunction):
+    def __init__(self, power_function, power_unit, ct_function, input_keys=['ws'],
+                 additional_models=default_additional_models):
+        PowerCtFunction.__init__(self, input_keys=input_keys, power_ct_func=self._power_ct, power_unit=power_unit,
+                                 additional_models=additional_models)
+        self.power_function = power_function
+        self.ct_function = ct_function
+
+    def _power_ct(self, ws, run_only):
+        return (self.power_function, self.ct_function)[run_only](ws)
+
+
+class CubePowerSimpleCt(PowerCtFunctions):
     """Simple analytical power function and constant ct (until ws_rated
     whereafter it follows a second order polynomal to ws_cutout,ct_idle)"""
 
@@ -406,7 +430,7 @@ class CubePowerSimpleCt(PowerCtFunction):
         additional_models : list, optional
             list of additional models.
         """
-        PowerCtFunction.__init__(self, ['ws'], self._power_ct, power_unit, [], additional_models)
+        PowerCtFunctions.__init__(self, self._power, power_unit, self._ct, additional_models=additional_models)
         self.ws_cutin = ws_cutin
         self.ws_rated = ws_rated
         self.ws_cutout = ws_cutout
@@ -425,14 +449,15 @@ class CubePowerSimpleCt(PowerCtFunction):
 
     def _power(self, ws):
         ws = np.asarray(ws)
+
+        def cube(x):
+            return x * x * x
+
         return np.where((ws > self.ws_cutin) & (ws <= self.ws_cutout),
-                        np.minimum(self.power_rated * ((ws - self.ws_cutin) / (self.ws_rated - self.ws_cutin))**3,
+                        np.minimum(self.power_rated * cube((ws - self.ws_cutin) / (self.ws_rated - self.ws_cutin)),
                                    self.power_rated),
                         0)
 
-    def _power_ct(self, ws, run_only):
-        return (self._power, self._ct)[run_only](ws)
-
     def _ct(self, ws):
         ws = np.asarray(ws)
 
@@ -450,22 +475,22 @@ class CubePowerSimpleCt(PowerCtFunction):
 
         return ct
 
-    def _power_ct_grad(self, ws, run_only):
-        if run_only == 0:
-            return np.where((ws > self.ws_cutin) & (ws <= self.ws_rated),
-                            3 * self.power_rated * (ws - self.ws_cutin)**2 / (self.ws_rated - self.ws_cutin)**3,
-                            0)
-        else:
-            dct = ws * 0
-            if self.ct_idle is not None:
-                dct = np.where((ws > self.ws_rated),
-                               self.dct_rated2cutout(ws),
-                               0)  # constant ct
-            return dct
-
-    @set_vjp(_power_ct_grad)
-    def _power_ct_withgrad(self, ws, run_only):
-        return (self._power, self._ct)[run_only](ws)
+    # def _power_ct_grad(self, ans, ws, run_only):
+    #     if run_only == 0:
+    #         return np.where((ws > self.ws_cutin) & (ws <= self.ws_rated),
+    #                         3 * self.power_rated * (ws - self.ws_cutin)**2 / (self.ws_rated - self.ws_cutin)**3,
+    #                         0)
+    #     else:
+    #         dct = ws * 0
+    #         if self.ct_idle is not None:
+    #             dct = np.where((ws > self.ws_rated),
+    #                            self.dct_rated2cutout(ws),
+    #                            0)  # constant ct
+    #         return dct
+    #
+    # @set_gradient_function(_power_ct_grad)
+    # def _power_ct_withgrad(self, ws, run_only):
+    #     return (self._power, self._ct)[run_only](ws)
 
 
 class PowerCtSurrogate(PowerCtFunction, FunctionSurrogates):
